@@ -4,7 +4,7 @@ use 5.008_005;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.06'; # Set automatically by milla
+our $VERSION = '0.07'; # Set automatically by milla
 
 my $based = {
 	'default.base' => 'Rest::HtmlVis::Base',
@@ -20,7 +20,7 @@ sub new {
 
 	### Set uri path
 	$self->{baseurl} = "/static";
-	$self->{baseurl} = $params->{'default.baseurl'} if exists $params->{'default.baseurl'};
+	$self->{baseurl} = delete $params->{'default.baseurl'} if exists $params->{'default.baseurl'};
 
 	### Add htmlvis
 	foreach my $key (sort keys %$params){
